<?php

namespace Drupal\monarch_bootstrap\Plugin\Alter\Form;

use Drupal\monarch_bootstrap\Plugin\Alter\AlterBase;

/**
 * Form alter plugin for the system_theme_settings form.
 *
 * @MonarchAlter("system_theme_settings")
 */
class SystemThemeSettingsAlter extends AlterBase {

  /**
   * {@inheritdoc}
   */
  public function alter(&$data, &$context1 = NULL, &$context2 = NULL) {
    $form = &$data;
    $form_state = $context1;
    $form_id = $context2;

    $theme_name = $this->getActiveTheme()->getName();

    $form['bootstrap'] = [
      '#type' => 'vertical_tabs',
      '#prefix' => '<h2><small>' . $this->t('Bootstrap Settings') . '</small></h2>',
      '#weight' => -10,
    ];
    $groups = [
      'regions' => $this->t('Regions'),
      'components' => $this->t('Components'),
    ];
    foreach ($groups as $group => $title) {
      $form[$group] = [
        '#type' => 'details',
        '#title' => $title,
        '#group' => 'bootstrap',
      ];
    }

    // Region settings.
    $regions = system_region_list($this->getActiveTheme()->getExtension());
    foreach ($regions as $region_key => $region) {
      $form['regions'][$region_key] = [
        '#type' => 'details',
        '#title' => $region,
        '#tree' => TRUE,
      ];

      $form['regions'][$region_key]['container'] = [
        '#type' => 'select',
        '#title' => $this->t('@region container', ['@region' => $region]),
        '#options' => [
          'none' => $this->t('None'),
          'container' => $this->t('Default'),
          'container-fluid' => $this->t('Fluid'),
          'container-sm' => $this->t('Small'),
          'container-md' => $this->t('Medium'),
          'container-lg' => $this->t('Large'),
          'container-xl' => $this->t('X-Large'),
          'container-xxl' => $this->t('XX-Large'),
        ],
        '#default_value' => theme_get_setting($region_key . '.container', $theme_name),
        '#description' => $this->t('Select the type of container to use for this region. See <a href=":url">https://getbootstrap.com/docs/5.1/layout/containers</a>', [':url' => 'https://getbootstrap.com/docs/5.1/layout/containers']),
      ];

      $form['regions'][$region_key]['bg_color'] = [
        '#type' => 'select',
        '#title' => $this->t('@region background color', ['@region' => $region]),
        '#options' => $this->getColorClassOptions(),
        '#default_value' => theme_get_setting($region_key . '.bg_color', $theme_name),
        '#description' => $this->t('Select the background color for this region. Colors are definied in variables.scss. Use "None" to exclude bootstrap background classes and allow customization in scss. See <a href=":url">https://getbootstrap.com/docs/5.1/customize/color/</a>', [':url' => 'https://getbootstrap.com/docs/5.1/customize/color/']),
      ];
    }

    // Component settings.
    $form['components']['card'] = [
      '#type' => 'details',
      '#title' => $this->t('Card'),
      '#tree' => TRUE,
      'button_class' => [
        '#type' => 'select',
        '#title' => $this->t('Card button color'),
        '#options' => $this->getColorClassOptions('btn'),
        '#default_value' => theme_get_setting('card.button_class', $theme_name),
        '#description' => $this->t('Select the default button color for card elements. Colors are definied in variables.scss. Use "None" to exclude a bootstrap color class and allow customization in scss. See <a href=":url">https://getbootstrap.com/docs/5.1/customize/color/</a>', [':url' => 'https://getbootstrap.com/docs/5.1/customize/color/']),
      ],
    ];

    $form['components']['input'] = [
      '#type' => 'details',
      '#title' => $this->t('Input'),
      '#tree' => TRUE,
      'submit_class' => [
        '#type' => 'select',
        '#title' => $this->t('Submit button color'),
        '#options' => $this->getColorClassOptions('btn'),
        '#default_value' => theme_get_setting('input.submit_class', $theme_name),
        '#description' => $this->t('Select the default button color for submit input elements. Colors are definied in variables.scss. Use "None" to exclude a bootstrap color class and allow customization in scss. See <a href=":url">https://getbootstrap.com/docs/5.1/customize/color/</a>', [':url' => 'https://getbootstrap.com/docs/5.1/customize/color/']),
      ],
      'button_class' => [
        '#type' => 'select',
        '#title' => $this->t('Default button color'),
        '#options' => $this->getColorClassOptions('btn'),
        '#default_value' => theme_get_setting('input.button_class', $theme_name),
        '#description' => $this->t('Select the default color for button elements. Colors are definied in variables.scss. Use "None" to exclude a bootstrap color class and allow customization in scss. See <a href=":url">https://getbootstrap.com/docs/5.1/customize/color/</a>', [':url' => 'https://getbootstrap.com/docs/5.1/customize/color/']),
      ],
    ];
  }

  /**
   * Return a list of available color classes.
   *
   * @param string $prefix
   *   The class prefix. eg. 'btn'. Default is 'bg'.
   *
   * @return mixed
   *   An array of bootstrap color class options.
   */
  private function getColorClassOptions(string $prefix = 'bg') {
    return [
      'none' => $this->t('None'),
      $prefix . '-primary' => $this->t('Primary'),
      $prefix . '-secondary' => $this->t('Secondary'),
      $prefix . '-success' => $this->t('Success'),
      $prefix . '-info' => $this->t('Info'),
      $prefix . '-warning' => $this->t('Warning'),
      $prefix . '-danger' => $this->t('Danger'),
      $prefix . '-light' => $this->t('Light'),
      $prefix . '-dark' => $this->t('Dark'),
    ];
  }

}
